use tide::prelude::*;

const SERVER_ADDRESS : &str = "127.0.0.1:8888";

#[derive(Deserialize, Serialize)]
struct UserInformation
{
    name : String
}

#[async_std::main]
async fn main() -> tide::Result<()>
{
    println!("http://{}/", SERVER_ADDRESS);

    let mut server : tide::Server<()> = tide::new();

    server.at("/")
        .get
        (
            |_| async
            {
                Ok
                (
                    tide::Response::builder(200)
                    .content_type(tide::http::mime::HTML)
                    .body
                    (
r#"<html>
<body>
<form action='hello'>
name : <input name='name' value='홍길동'>
<input type='submit' value='전송'>
</form>
</body>
</html>"#
                    )
                    .build()
                )
            }
        );

    server.at("/hello")
        .get
        (
            |request : tide::Request<()>| async move
            {
                let user_information : UserInformation = request.query()?;

                return Ok
                (
                    tide::Response::builder(200)
                        .content_type(tide::http::mime::HTML)
                        .body(format!("<h1>안녕하세요, {}님</h1>", user_information.name))
                        .build()
                );
            }
        );

    server.listen(SERVER_ADDRESS).await?;

    return Ok(());
}